*Developed by A.J. May (<aj7may@gmail.com>)*

...and the folowing Django Password Strength contributors:

- Telonor
- Allard Stijnman ([snoepkast](https://github.com/snoepkast))
- Merouane Atig ([merwan](https://github.com/merwan))
